@@ -1390,17 +1390,15 @@ HostIF_LookupUserMPN(VMDriver *vm, // IN: VMDriver
                       "now back at %#x\n", 
 		      uvAddr, current->comm, current->pid, mpn);
 #endif
-	    } else if (mpn) {
+	    } else if (mpn != INVALID_MPN) {
 	       printk(KERN_DEBUG "Page %p disappeared from %s(%u)... "
                       "now back at %#x (old=%#x)\n", uvAddr, current->comm, 
                       current->pid, mpn, entryPtr->mpn);
 	       mpn = INVALID_MPN;
 	    } else {
-#ifdef VMX86_DEBUG
 	       printk(KERN_DEBUG "Page %p disappeared from %s(%u)... "
                       "and is lost (old=%#x)\n", uvAddr, current->comm, 
                       current->pid, entryPtr->mpn);
-#endif		      
 	       mpn = entryPtr->mpn;
 	    }
 	 }
